==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/pt_PT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Partilhado com terceiros",
    "Shared with you" : "Partilhado consigo ",
    "Shared by link" : "Partilhado por hiperligação",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others share with you will show up here" : "Os ficheiros e pastas que terceiros partilham consigo, serão mostrados aqui",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you share will show up here" : "Os ficheiros e as pastas que partilha serão mostrados aqui",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha com esta hiperligação, serão mostrados aqui",
    "You can upload into this folder" : "Pode enviar para esta pasta",
    "No compatible server found at {remote}" : "Nenhum servidor compatível encontrado em {remote}",
    "Invalid server URL" : "URL de servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Falha a adicionar hiperligação pública ao seu Nextcloud",
    "Share" : "Partilhar",
    "No expiration date set" : "Data de expiração não definida",
    "Shared by" : "Partilhado por",
    "Sharing" : "Partilha",
    "File shares" : "Partilhas de ficheiro",
    "Downloaded via public link" : "Transferido via hiperligação pública",
    "Downloaded by {email}" : "Descarregado por {email}",
    "{file} downloaded via public link" : "{file} descarregado através de uma hiperligação pública",
    "{email} downloaded {file}" : "{email} descarregou {file}",
    "Shared with group {group}" : "Partilhado com o grupo {group}",
    "Removed share for group {group}" : "Removeu a partilha para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} partilhou com o grupo {group}",
    "{actor} removed share for group {group}" : "{actor} removeu a partilha para o grupo {group}",
    "You shared {file} with group {group}" : "Partilhaste {file} com o grupo {group}",
    "You removed group {group} from {file}" : "Removeste o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} partilhou {file} com o grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} removeu o grupo {group} de {file}",
    "Shared as public link" : "Partilhado como hiperligação pública",
    "Removed public link" : "Hiperligação pública removida",
    "Public link expired" : "A hiperligação pública expirou",
    "{actor} shared as public link" : "{actor} partilhou como hiperligação pública",
    "{actor} removed public link" : "{actor} removeu a hiperligação pública",
    "Public link of {actor} expired" : "Hiperligação pública de {actor} expirou",
    "You shared {file} as public link" : "Partilhaste {file} como hiperligação pública",
    "You removed public link for {file}" : "Removeste hiperligação pública de {file}",
    "Public link expired for {file}" : "Hiperligação pública expirada para {file}",
    "{actor} shared {file} as public link" : "{actor} partilhou {file} como hiperligação pública",
    "{actor} removed public link for {file}" : "{actor} removeu hiperligação pública de {file}",
    "Public link of {actor} for {file} expired" : "Hiperligação pública de {actor} para {file} expirou",
    "{user} accepted the remote share" : "{user} aceitou a partilha remota",
    "{user} declined the remote share" : "{user} rejeitou a partilha remota",
    "You received a new remote share {file} from {user}" : "Recebeu uma nova partilha remota {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceitou a partilha remota de {file}",
    "{user} declined the remote share of {file}" : "{user} rejeitou a partilha remota de {file}",
    "{user} unshared {file} from you" : "{user} cancelou a partilha de {file} consigo",
    "Shared with {user}" : "Partilhado com {user}",
    "Removed share for {user}" : "Partilha removida para {user}",
    "{actor} shared with {user}" : "{actor} partilhou com {user}",
    "{actor} removed share for {user}" : "{actor} removeu partilha com {user}",
    "Shared by {actor}" : "Partilhado por {actor}",
    "{actor} removed share" : "{actor} removeu partilha",
    "You shared {file} with {user}" : "Partilhaste {file} com {user}",
    "You removed {user} from {file}" : "Removeste {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} partilhou {file} com {user}",
    "{actor} removed {user} from {file}" : "{actor} removeu {user} de {file}",
    "{actor} shared {file} with you" : "{actor} partilhou {file} consigo",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Um ficheiro ou pasta partilhado por email ou hiperligação publica foi  <strong>descarregado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "Wrong share ID, share doesn't exist" : "Id. de partilha errada, a partilha não existe",
    "could not delete share" : "Não foi possível eliminar a partilha",
    "Could not delete share" : "Não foi possível eliminar a partilha",
    "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, ficheiro/pasta não existe",
    "Could not create share" : "Não foi possível criar partilha",
    "invalid permissions" : "permissões inválidas",
    "Please specify a valid user" : "Por favor, especifique um utilizador válido",
    "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
    "Please specify a valid group" : "Por favor, especifique um grupo válido",
    "Public link sharing is disabled by the administrator" : "A partilha da hiperligação pública está desativada pelo administrador",
    "Public upload disabled by the administrator" : "Envio público desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "O envio público só é possível para as pastas partilhadas publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "A partilha de %s falhou porque \"back end\" não permite partilhas do tipo %s",
    "You cannot share to a Circle if the app is not enabled" : "Não pode partilhar um Círculo se a aplicação não estiver activa",
    "Please specify a valid circle" : "Por favor especifique um círculo válido",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "Not a directory" : "Não é uma diretoria",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Wrong or no update parameter given" : "Parâmetro indicado errado ou desatualizado",
    "Can't change permissions for public share links" : "Não é possível alterar as permissões para as hiperligações de partilha pública",
    "Cannot increase permissions" : "Não é possível incrementar as permissões",
    "shared by %s" : "partilhado por %s",
    "Download" : "Transferir",
    "Direct link" : "Hiperligação direta",
    "Add to your Nextcloud" : "Adicionar à sua Nextcloud",
    "Share API is disabled" : "A partilha de API está desativada",
    "File sharing" : "Partilha de ficheiro",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Share time" : "Hora da Partilha",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, mas esta hiperligação parece já não estar a funcionar.",
    "Reasons might be:" : "As razões poderão ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "a hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "Download %s" : "Transferir %s",
    "Upload files to %s" : "Enviar ficheiros para %s",
    "Select or drop files" : "Seleccione ou solte ficheiros",
    "Uploading files…" : "A enviar ficheiros...",
    "Uploaded files:" : "Ficheiros enviados:",
    "{actor} removed you from {file}" : "{actor} removeu-o de {file}",
    "%s is publicly shared" : "%s está partilhado publicamente",
    "This share is password-protected" : "Esta partilha está protegida por palavra-passe",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Password" : "Palavra-passe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/pt_PT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Partilhado com terceiros",
    "Shared with you" : "Partilhado consigo ",
    "Shared by link" : "Partilhado por hiperligação",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others share with you will show up here" : "Os ficheiros e pastas que terceiros partilham consigo, serão mostrados aqui",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you share will show up here" : "Os ficheiros e as pastas que partilha serão mostrados aqui",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha com esta hiperligação, serão mostrados aqui",
    "Download" : "Transferir",
    "You can upload into this folder" : "Pode enviar para esta pasta",
    "No compatible server found at {remote}" : "Nenhum servidor compatível encontrado em {remote}",
    "Invalid server URL" : "URL de servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Falha a adicionar hiperligação pública ao seu Nextcloud",
    "Share" : "Partilhar",
    "No expiration date set" : "Data de expiração não definida",
    "Shared by" : "Partilhado por",
    "Sharing" : "Partilha",
    "File shares" : "Partilhas de ficheiro",
    "Downloaded via public link" : "Transferido via hiperligação pública",
    "Downloaded by {email}" : "Transferido por {email}",
    "{file} downloaded via public link" : "{file} transferido via hiperligação pública",
    "{email} downloaded {file}" : "{email} transferiu {file}",
    "Shared with group {group}" : "Partilhado com o grupo {group}",
    "Removed share for group {group}" : "Removeu a partilha para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} partilhou com o grupo {group}",
    "{actor} removed share for group {group}" : "{actor} removeu a partilha para o grupo {group}",
    "You shared {file} with group {group}" : "Partilhaste {file} com o grupo {group}",
    "You removed group {group} from {file}" : "Removeste o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} partilhou {file} com o grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} removeu o grupo {group} de {file}",
    "Shared as public link" : "Partilhado como hiperligação pública",
    "Removed public link" : "Hiperligação pública removida",
    "Public link expired" : "A hiperligação pública expirou",
    "{actor} shared as public link" : "{actor} partilhou como hiperligação pública",
    "{actor} removed public link" : "{actor} removeu a hiperligação pública",
    "Public link of {actor} expired" : "Hiperligação pública de {actor} expirou",
    "You shared {file} as public link" : "Partilhaste {file} como hiperligação pública",
    "You removed public link for {file}" : "Removeste hiperligação pública de {file}",
    "Public link expired for {file}" : "Hiperligação pública expirada para {file}",
    "{actor} shared {file} as public link" : "{actor} partilhou {file} como hiperligação pública",
    "{actor} removed public link for {file}" : "{actor} removeu hiperligação pública de {file}",
    "Public link of {actor} for {file} expired" : "Hiperligação pública de {actor} para {file} expirou",
    "{user} accepted the remote share" : "{user} aceitou a partilha remota",
    "{user} declined the remote share" : "{user} rejeitou a partilha remota",
    "You received a new remote share {file} from {user}" : "Recebeu uma nova partilha remota {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceitou a partilha remota de {file}",
    "{user} declined the remote share of {file}" : "{user} rejeitou a partilha remota de {file}",
    "{user} unshared {file} from you" : "{user} cancelou a partilha de {file} consigo",
    "Shared with {user}" : "Partilhado com {user}",
    "Removed share for {user}" : "Partilha removida para {user}",
    "{actor} shared with {user}" : "{actor} partilhou com {user}",
    "{actor} removed share for {user}" : "{actor} removeu partilha com {user}",
    "Shared by {actor}" : "Partilhado por {actor}",
    "{actor} removed share" : "{actor} removeu partilha",
    "You shared {file} with {user}" : "Partilhaste {file} com {user}",
    "You removed {user} from {file}" : "Removeste {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} partilhou {file} com {user}",
    "{actor} removed {user} from {file}" : "{actor} removeu {user} de {file}",
    "{actor} shared {file} with you" : "{actor} partilhou {file} consigo",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Um ficheiro ou pasta partilhado por e-mail ou hiperligação publica foi  transferido</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "Wrong share ID, share doesn't exist" : "Id. de partilha errada, a partilha não existe",
    "could not delete share" : "Não foi possível eliminar a partilha",
    "Could not delete share" : "Não foi possível eliminar a partilha",
    "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, ficheiro/pasta não existe",
    "Could not create share" : "Não foi possível criar partilha",
    "invalid permissions" : "permissões inválidas",
    "Please specify a valid user" : "Por favor, especifique um utilizador válido",
    "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
    "Please specify a valid group" : "Por favor, especifique um grupo válido",
    "Public link sharing is disabled by the administrator" : "A partilha da hiperligação pública está desativada pelo administrador",
    "Public upload disabled by the administrator" : "Envio público desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "O envio público só é possível para as pastas partilhadas publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Não pode partilhar um Círculo se a aplicação não estiver activa",
    "Please specify a valid circle" : "Por favor especifique um círculo válido",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "Not a directory" : "Não é uma diretoria",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Wrong or no update parameter given" : "Parâmetro indicado errado ou desatualizado",
    "Can't change permissions for public share links" : "Não é possível alterar as permissões para as hiperligações de partilha pública",
    "Cannot increase permissions" : "Não é possível incrementar as permissões",
    "shared by %s" : "partilhado por %s",
    "Direct link" : "Hiperligação direta",
    "Add to your Nextcloud" : "Adicionar à sua Nextcloud",
    "Share API is disabled" : "A partilha de API está desativada",
    "File sharing" : "Partilha de ficheiro",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Share time" : "Hora da Partilha",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, mas esta hiperligação parece já não estar a funcionar.",
    "Reasons might be:" : "As razões poderão ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "a hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "Download %s" : "Transferir %s",
    "Upload files to %s" : "Enviar ficheiros para %s",
    "Select or drop files" : "Seleccione ou solte ficheiros",
    "Uploading files…" : "A enviar ficheiros...",
    "Uploaded files:" : "Ficheiros enviados:",
    "{actor} removed you from {file}" : "{actor} removeu-o de {file}",
    "Sharing %s failed because the back end does not allow shares from type %s" : "A partilha de %s falhou porque \"back end\" não permite partilhas do tipo %s",
    "%s is publicly shared" : "%s está partilhado publicamente",
    "This share is password-protected" : "Esta partilha está protegida por palavra-passe",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Password" : "Palavra-passe"
},
"nplurals=2; plural=(n != 1);");
